package cn.com.infosec.ocsp;

import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.ocsp.CertStatus;
import cn.com.infosec.asn1.ocsp.RevokedInfo;
import cn.com.infosec.asn1.ocsp.SingleResponse;
import cn.com.infosec.asn1.x509.X509Extensions;
import java.io.ByteArrayOutputStream;
import java.security.cert.X509Extension;
import java.text.ParseException;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Set;

public class SingleResp implements X509Extension {
   SingleResponse resp;

   public SingleResp(SingleResponse resp) {
      this.resp = resp;
   }

   private Set getExtensionOIDs(boolean critical) {
      SingleResp var10000 = this;
      HashSet var5;
      var5 = new HashSet.<init>();
      X509Extensions var2;
      if ((var2 = var10000.getSingleExtensions()) != null) {
         Enumeration var3 = var2.oids();

         while(var3.hasMoreElements()) {
            DERObjectIdentifier var4;
            if (critical == var2.getExtension(var4 = (DERObjectIdentifier)var3.nextElement()).isCritical()) {
               var5.add(var4.getId());
            }
         }
      }

      return var5;
   }

   public CertificateID getCertID() {
      return new CertificateID(this.resp.getCertID());
   }

   public Object getCertStatus() {
      CertStatus var1;
      if ((var1 = this.resp.getCertStatus()).getTagNo() == 0) {
         return null;
      } else {
         return var1.getTagNo() == 1 ? new RevokedStatus(RevokedInfo.getInstance(var1.getStatus())) : new UnknownStatus();
      }
   }

   public Date getThisUpdate() {
      try {
         return this.resp.getThisUpdate().getDate();
      } catch (ParseException var1) {
         throw new IllegalStateException("ParseException: " + var1.getMessage());
      }
   }

   public Date getNextUpdate() {
      if (this.resp.getNextUpdate() == null) {
         return null;
      } else {
         try {
            return this.resp.getNextUpdate().getDate();
         } catch (ParseException var1) {
            throw new IllegalStateException("ParseException: " + var1.getMessage());
         }
      }
   }

   public X509Extensions getSingleExtensions() {
      return this.resp.getSingleExtensions();
   }

   public boolean hasUnsupportedCriticalExtension() {
      Set var1;
      return (var1 = this.getCriticalExtensionOIDs()) != null && !var1.isEmpty();
   }

   public Set getCriticalExtensionOIDs() {
      return this.getExtensionOIDs(true);
   }

   public Set getNonCriticalExtensionOIDs() {
      return this.getExtensionOIDs(false);
   }

   public byte[] getExtensionValue(String oid) {
      X509Extensions var3;
      if ((var3 = this.getSingleExtensions()) != null) {
         X509Extensions var10000 = var3;
         DERObjectIdentifier var5;
         var5 = new DERObjectIdentifier.<init>(oid);
         cn.com.infosec.asn1.x509.X509Extension var6;
         if ((var6 = var10000.getExtension(var5)) != null) {
            ByteArrayOutputStream oid1;
            ByteArrayOutputStream var4 = oid1 = new ByteArrayOutputStream;
            var4.<init>();
            cn.com.infosec.asn1.x509.X509Extension var10002 = var6;
            DEROutputStream var10001 = new DEROutputStream(oid1);

            try {
               var10001.writeObject(var10002.getValue());
               return var4.toByteArray();
            } catch (Exception var2) {
               throw new RuntimeException("error encoding " + var2.toString());
            }
         }
      }

      return null;
   }
}
